/*
 * Copyright (c) 2019 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include "screen_connector_launcher_service/raw_image.h"
#include "screen_connector_launcher_service/log_internal.h"

namespace screen_connector {

RawImage::RawImage(Direction direction,
                   int32_t x, int32_t y,
                   std::string shared_widget_info,
                   std::shared_ptr<ImageFile> image_file)
  : image_type_(ImageType::RemoteSurfaceImageFile),
    direction_(direction),
    x_(x), y_(y),
    shared_widget_info_(std::move(shared_widget_info)) {
  image_file_ = std::move(image_file);
}

RawImage::RawImage(Direction direction,
                   int32_t x, int32_t y,
                   std::string shared_widget_info,
                   std::shared_ptr<WlBuffer> wl_buffer)
  : image_type_(ImageType::RemoteSurfaceTBM),
    direction_(direction),
    x_(x), y_(y),
    shared_widget_info_(std::move(shared_widget_info)) {
  wl_buffer_ = std::move(wl_buffer);
}

RawImage::RawImage(Direction direction,
                   int32_t x, int32_t y,
                   std::string shared_widget_info,
                   std::string file_path)
  : image_type_(ImageType::SplashScreenImage),
    direction_(direction),
    x_(x), y_(y),
    shared_widget_info_(std::move(shared_widget_info)) {
  file_path_ = std::move(file_path);
}

RawImage::RawImage(Direction direction,
                   int32_t x, int32_t y,
                   std::string shared_widget_info,
                   std::string file_path,
                   std::string file_group)
  : image_type_(ImageType::SplashScreenEdje),
    direction_(direction),
    x_(x), y_(y),
    shared_widget_info_(std::move(shared_widget_info)) {
  file_path_ = std::move(file_path);
  file_group_ = std::move(file_group);
}

RawImage::~RawImage() = default;

ImageType RawImage::GetImageType() const {
  return image_type_;
}

Direction RawImage::GetDirection() const {
  return direction_;
}

int32_t RawImage::GetPositionX() const {
  return x_;
}

int32_t RawImage::GetPositionY() const {
  return y_;
}

std::string RawImage::GetSharedWidgetInfo() const {
  return shared_widget_info_;
}

std::shared_ptr<WlBuffer> RawImage::GetWlBuffer() const {
  return wl_buffer_;
}

std::shared_ptr<ImageFile> RawImage::GetImageFile() const {
  return image_file_;
}

std::string RawImage::GetFilePath() const {
  return file_path_;
}

std::string RawImage::GetFileGroup() const {
  return file_group_;
}

}  // namespace screen_connector
