/*
 * Copyright (c) 2019 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef SCREEN_CONNECTOR_LAUNCHER_SERVICE_TIZEN_REMOTE_SURFACE_INTERNAL_H_
#define SCREEN_CONNECTOR_LAUNCHER_SERVICE_TIZEN_REMOTE_SURFACE_INTERNAL_H_

#include <stdint.h>
#include <tizen-remote-surface-client-protocol.h>
#include <unistd.h>

#include <string>
#include <memory>

#include "screen_connector_common/handle.h"
#include "screen_connector_common/wl_buffer.h"
#include "screen_connector_launcher_service/direction.h"

namespace screen_connector {

class TizenRemoteSurface : public Handle<struct tizen_remote_surface*> {
 public:
  class IEventListener {
   public:
    virtual void OnRawBufferUpdated(std::shared_ptr<WlBuffer> wl_buffer,
                                    uint32_t time,
                                    uint32_t serial) = 0;
    virtual void OnRawBufferMissing(uint32_t serial) = 0;
    virtual void OnRawBufferChanged(uint32_t type,
                                    std::shared_ptr<WlBuffer> wl_buffer,
                                    int32_t fd,
                                    uint32_t size,
                                    uint32_t time,
                                    Direction direction,
                                    int32_t x,
                                    int32_t y,
                                    const std::string& shared_widget_info,
                                    uint32_t serial) = 0;
    virtual void OnInputFilterChanged(uint32_t event_filter,
                                      uint32_t serial) = 0;
  };

  TizenRemoteSurface(struct tizen_remote_surface* raw,
                     Direction direction,
                     int32_t x, int32_t y,
                     std::string shared_widget_info,
                     uint32_t serial);
  virtual ~TizenRemoteSurface();

  struct tizen_remote_surface* GetHandle() const;

  void AddListener(IEventListener* listener);
  IEventListener* GetListener();

  Direction GetDirection() const;
  int32_t GetPositionX() const;
  int32_t GetPositionY() const;
  const std::string& GetSharedWidgetInfo() const;
  uint32_t GetSerial() const;
  void Redirect();

 private:
  static void BufferUpdatedCB(void* data,
                              struct tizen_remote_surface* trs,
                              struct wl_buffer* buffer,
                              uint32_t time);
  static void BufferMissingCB(void* data,
                              struct tizen_remote_surface* trs);
  static void BufferChangedCB(void* data,
                              struct tizen_remote_surface* trs,
                              uint32_t type,
                              struct wl_buffer* tbm,
                              int32_t img_fd,
                              uint32_t img_file_size,
                              uint32_t time,
                              struct wl_array* keys);
  static void InputEventFilterCB(void* data,
                                 struct tizen_remote_surface* trs,
                                 uint32_t event_filter);

 private:
  Direction direction_;
  int32_t x_;
  int32_t y_;
  std::string shared_widget_info_;
  uint32_t serial_;
  IEventListener* listener_ = nullptr;
};

}  // namespace screen_connector

#endif  // SCREEN_CONNECTOR_LAUNCHER_SERVICE_TIZEN_REMOTE_SURFACE_INTERNAL_H_
