/*
 * Copyright (c) 2019 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef SCREEN_CONNECTOR_LAUNCHER_SERVICE_EVAS_INCLUDE_SCREEN_CONNECTOR_LAUNCHER_SERVICE_EVAS_H_
#define SCREEN_CONNECTOR_LAUNCHER_SERVICE_EVAS_INCLUDE_SCREEN_CONNECTOR_LAUNCHER_SERVICE_EVAS_H_

#include <stdbool.h>
#include <stdint.h>

#include <Elementary.h>
#include <tizen.h>

#ifdef __cplusplus
extern "C" {
#endif

typedef enum {
  SCREEN_CONNECTOR_LAUNCHER_SERVICE_EVAS_ERROR_NONE,
  SCREEN_CONNECTOR_LAUNCHER_SERVICE_EVAS_ERROR_DISQUALIFIED,
  SCREEN_CONNECTOR_LAUNCHER_SERVICE_EVAS_ERROR_WRONG_REQUEST,
} screen_connector_launcher_service_evas_error_e;

typedef enum {
  SCREEN_CONNECTOR_LAUNCHER_SERVICE_EVAS_DIRECTION_FORWARD,
  SCREEN_CONNECTOR_LAUNCHER_SERVICE_EVAS_DIRECTION_BACKWARD,
} screen_connector_launcher_service_evas_direction_e;

typedef enum {
  SCREEN_CONNECTOR_LAUNCHER_SERVICE_EVAS_IMAGE_TYPE_REMOTE_SURFACE_TBM,
  SCREEN_CONNECTOR_LAUNCHER_SERVICE_EVAS_IMAGE_TYPE_REMOTE_SURFACE_IMAGE_FILE,
  SCREEN_CONNECTOR_LAUNCHER_SERVICE_EVAS_IMAGE_TYPE_SPLASH_SCREEN_IMAGE,
  SCREEN_CONNECTOR_LAUNCHER_SERVICE_EVAS_IMAGE_TYPE_SPLASH_SCREEN_EDJE,
} screen_connector_launcher_service_evas_image_type_e;

typedef void* screen_connector_launcher_service_evas_h;

typedef void (*screen_connector_launcher_service_evas_prepare_cb)(
  Evas_Object* image,
  screen_connector_launcher_service_evas_image_type_e image_type,
  screen_connector_launcher_service_evas_direction_e direction,
  int32_t x,
  int32_t y,
  const char* shared_widget_info,
  uint32_t serial,
  void* user_data);

typedef void (*screen_connector_launcher_service_evas_stop_cb)(
  uint32_t serial,
  void* user_data);

typedef void (*screen_connector_launcher_service_evas_error_cb)(
  screen_connector_launcher_service_evas_error_e error,
  uint32_t serial,
  void* user_data);

typedef void (*screen_connector_launcher_service_evas_cleanup_cb)(
  uint32_t serial,
  void* user_data);

typedef struct {
  screen_connector_launcher_service_evas_prepare_cb prepare;
  screen_connector_launcher_service_evas_stop_cb stop;
  screen_connector_launcher_service_evas_error_cb error;
  screen_connector_launcher_service_evas_cleanup_cb cleanup;
} screen_connector_launcher_service_evas_ops;

int screen_connector_launcher_service_evas_create(
  Evas_Object* win,
  screen_connector_launcher_service_evas_h* handle);

int screen_connector_launcher_service_evas_destroy(
  screen_connector_launcher_service_evas_h handle);

int screen_connector_launcher_service_evas_set_ops(
  screen_connector_launcher_service_evas_h handle,
  screen_connector_launcher_service_evas_ops *ops,
  void* user_data);

int screen_connector_launcher_service_evas_launch(
  screen_connector_launcher_service_evas_h handle,
  const char* app_id,
  const char* inst_id,
  int pid,
  uint32_t serial);

int screen_connector_launcher_service_evas_launch_with_shared_widget(
  screen_connector_launcher_service_evas_h handle,
  const char* app_id,
  const char* inst_id,
  int pid,
  uint32_t serial);

int screen_connector_launcher_service_evas_launching(
  screen_connector_launcher_service_evas_h handle,
  uint32_t serial);

int screen_connector_launcher_service_evas_launch_cancel(
  screen_connector_launcher_service_evas_h handle,
  uint32_t serial);

int screen_connector_launcher_service_evas_launch_done(
  screen_connector_launcher_service_evas_h handle,
  uint32_t serial);

#ifdef __cplusplus
}
#endif

#endif  // SCREEN_CONNECTOR_LAUNCHER_SERVICE_EVAS_INCLUDE_SCREEN_CONNECTOR_LAUNCHER_SERVICE_EVAS_H_
