/*
 * Copyright (c) 2017 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef SCREEN_CONNECTOR_REMOTE_SURFACE_EVAS_REMOTE_SURFACE_EVAS_IMPLEMENTATION_H_
#define SCREEN_CONNECTOR_REMOTE_SURFACE_EVAS_REMOTE_SURFACE_EVAS_IMPLEMENTATION_H_

#include <string>
#include <memory>
#include <map>

#include "screen_connector_remote_surface_evas/evas_event_interface.h"
#include "screen_connector_remote_surface/remote_surface.h"
#include "screen_connector_remote_surface_evas/remote_surface_evas.h"
#include "screen_connector_remote_surface_evas/image_internal.h"

namespace screen_connector {

class RemoteSurfaceEvas::Impl : public Image::IEventListener {
 public:
  void OnMouseIn(const EvasObject& obj, void* eventInfo) override;
  void OnMouseOut(const EvasObject& obj, void* eventInfo) override;
  void OnMouseDown(const EvasObject& obj, void* eventInfo) override;
  void OnMouseUp(const EvasObject& obj, void* eventInfo) override;
  void OnTouchMultiDown(const EvasObject& obj, void* eventInfo) override;
  void OnTouchMultiUp(const EvasObject& obj, void* eventInfo) override;
  void OnMouseMove(const EvasObject& obj, void* eventInfo) override;
  void OnMouseWheel(const EvasObject& obj, void* eventInfo) override;
  void OnMove(const EvasObject& obj, void* eventInfo) override;
  void OnShow(const EvasObject& obj, void* eventInfo) override;
  void OnHide(const EvasObject& obj, void* eventInfo) override;
  void OnResize(const EvasObject& obj, void* eventInfo) override;

  virtual ~Impl() = default;

 private:
  Impl(RemoteSurfaceEvas* parent,
      std::shared_ptr<EvasObject> viewerWin, bool mock);


 private:
  friend class RemoteSurfaceEvas;

  std::shared_ptr<EvasObject> viewer_win_;
  std::unique_ptr<Image> img_tbm_;
  bool is_init_ = false;
  RemoteSurfaceEvas::Visibility visibility_ = RemoteSurfaceEvas::UNKNOWN;
  std::map<int, RemoteSurfaceEvas::Visibility> winVisibility_map_;
  int bind_win_id_ = 0;
  bool flick_ = false;
  int prev_y_ = 0;
  RemoteSurfaceEvas* parent_;
  bool mock_;
};

}  // namespace screen_connector

#endif  // SCREEN_CONNECTOR_REMOTE_SURFACE_EVAS_REMOTE_SURFACE_EVAS_IMPLEMENTATION_H_
